==> camel-api-3.11.1-sources.jar: org/apache/camel/CamelContextAware.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel;

/**
 * An interface to represent an object which wishes to be injected with the {@link CamelContext}
 */
public interface CamelContextAware {

    /**
     * Set the {@link CamelContext} context if the object is an instance of {@link CamelContextAware}.
     */
    static <T> T trySetCamelContext(T object, CamelContext camelContext) {
        if (object instanceof CamelContextAware) {
            ((CamelContextAware) object).setCamelContext(camelContext);
        }

        return object;
    }

    /**
     * Get the {@link CamelContext}
     *
     * @return camelContext the Camel context
     */
    CamelContext getCamelContext();

    /**
     * Injects the {@link CamelContext}
     *
     * @param camelContext the Camel context
     */
    void setCamelContext(CamelContext camelContext);
}

==> camel-api-3.21.0-sources.jar: org/apache/camel/CamelContextAware.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel;

/**
 * An interface to represent an object which wishes to be injected with the {@link CamelContext}
 */
public interface CamelContextAware {

    /**
     * Set the {@link CamelContext} context if the object is an instance of {@link CamelContextAware}.
     */
    static <T> T trySetCamelContext(T object, CamelContext camelContext) {
        if (camelContext != null && object instanceof CamelContextAware) {
            ((CamelContextAware) object).setCamelContext(camelContext);
        }

        return object;
    }

    /**
     * Get the {@link CamelContext}
     *
     * @return the Camel context
     */
    CamelContext getCamelContext();

    /**
     * Injects the {@link CamelContext}
     *
     * @param camelContext the Camel context
     */
    void setCamelContext(CamelContext camelContext);
}
